
%global ppp_version %(pkg-config --modversion pppd 2>/dev/null || sed -n 's/^#define\\s*VERSION\\s*"\\([^\\s]*\\)"$/\\1/p' %{_includedir}/pppd/patchlevel.h 2>/dev/null | grep . || echo bad)
%global glib2_version %(pkg-config --modversion glib-2.0 2>/dev/null || echo bad)

%global real_version 1.44.2
%global rpm_version %{real_version}

%global obsoletes_device_plugins     0.9.9.95-1
%global obsoletes_ppp_plugin         1.5.3

%global nmlibdir %{_prefix}/lib/%{name}
%global nmplugindir %{_libdir}/%{name}/%{version}-%{release}

%global _hardened_build 1

%global real_version_major %(printf '%s' '%{real_version}' | sed -n 's/^\\([1-9][0-9]*\\.[0-9][0-9]*\\)\\.[0-9][0-9]*$/\\1/p')
%global systemd_units NetworkManager.service NetworkManager-wait-online.service NetworkManager-dispatcher.service nm-priv-helper.service
%global systemd_units_cloud_setup nm-cloud-setup.service nm-cloud-setup.timer

###############################################################################

%bcond_without adsl
%bcond_without nm_cloud_setup
%bcond_without ppp
%bcond_without team
%bcond_without bluetooth
%bcond_without iwd
%bcond_without ovs
%bcond_without wifi
%bcond_without wwan

%global dbus_version 1.14.0
%global dbus_sys_dir %{_datadir}/dbus-1/system.d
%global libndp_version 1.7-4

%if %{with bluetooth} || %{with wwan}
%global with_modem_manager_1 1
%else
%global with_modem_manager_1 0
%endif

%global dhcp_default internal
%global logging_backend_default journal
%global dns_rc_manager_default auto
%global config_plugins_default_ifcfg_rh 0
%global config_plugins_default keyfile
%global ebpf_enabled "no"

Name: NetworkManager
Summary: Network connection manager and user applications
Version: %{rpm_version}
Release: 7%{?dist}
Group: System Environment/Base
License: GPLv2+ and LGPLv2+
URL: https://networkmanager.dev/

Source0: https://download.gnome.org/sources/NetworkManager/%{real_version_major}/%{name}-%{real_version}.tar.xz
Source1: NetworkManager.conf
Source2: 00-server.conf
Source6: 70-nm-connectivity.conf

Patch0001: NetworkManager-fix-CVE-2024-3661.patch
Patch0002: https://gitlab.freedesktop.org/NetworkManager/NetworkManager/-/commit/9c42177d0936f9cbfc0dcbfb994821dad8322ed7.patch
Patch3000: NetworkManager-fix-CVE-2024-6501.patch

Requires(post): systemd
Requires(post): systemd-udev
Requires(post): /usr/sbin/update-alternatives
Requires(preun): systemd
Requires(preun): /usr/sbin/update-alternatives
Requires(postun): systemd

Requires: dbus >= %{dbus_version}
Requires: glib2 >= %{glib2_version}
Requires: %{name}-libnm = %{version}-%{release}
%if "%{libndp_version}" != ""
Requires: libndp >= %{libndp_version}
%endif
Obsoletes: NetworkManager < %{obsoletes_ppp_plugin}
Obsoletes: NetworkManager-wimax < 1.2

Conflicts: NetworkManager-vpnc < 0.7.0.99-1
Conflicts: NetworkManager-openvpn < 0.7.0.99-1
Conflicts: NetworkManager-pptp < 0.7.0.99-1
Conflicts: NetworkManager-openconnect < 0.7.0.99-1
Conflicts: kde-plasma-networkmanagement < 0.9-0.49.20110527git.nm09

BuildRequires: automake autoconf
%ifnarch loongarch64
BuildRequires: vala
%endif
BuildRequires: make gcc libtool pkgconfig libxslt iproute firewalld-filesystem gtk-doc
BuildRequires: dhclient readline-devel audit-libs-devel systemd-devel libcurl-devel libudev-devel libuuid-devel libselinux-devel polkit-devel jansson-devel newt-devel 
BuildRequires: python3 python3-gobject-base python3-dbus python3-pexpect
BuildRequires: gnutls gnutls-devel
BuildRequires: /usr/bin/dbus-launch

BuildRequires: gettext-devel >= 0.19.8
BuildRequires: dbus-devel >= %{dbus_version}
BuildRequires: glib2-devel >= 2.40.0
BuildRequires: gobject-introspection-devel >= 0.10.3
BuildRequires: systemd >= 200-3
BuildRequires: libpsl-devel >= 0.1
BuildRequires: libndp-devel >= 1.0

BuildRequires: iproute-tc

%if %{with ppp}
BuildRequires: ppp-devel >= 2.4.5
%endif

%if %{with bluetooth}
BuildRequires: bluez-libs-devel
%endif

%if 0%{?with_modem_manager_1}
BuildRequires: ModemManager-glib-devel >= 1.0
%endif

%if %{with wwan}
BuildRequires: mobile-broadband-provider-info-devel
%endif

Provides: %{name}-dispatcher = %{version}-%{release}
Provides: bundled(systemd) = 0

%description
NetworkManager is a system service that manages network interfaces and
connections based on user or automatic configuration. It supports
Ethernet, Bridge, Bond, VLAN, Team, InfiniBand, Wi-Fi, mobile broadband
(WWAN), PPPoE and other devices, and supports a variety of different VPN
services.

%if %{with adsl}
%package adsl
Summary: ADSL device plugin for NetworkManager
Group: System Environment/Base
Requires: %{name} = %{version}-%{release}
Obsoletes: NetworkManager < %{obsoletes_device_plugins}

%description adsl
This package contains NetworkManager support for ADSL devices.
%endif

%if %{with bluetooth}
%package bluetooth
Summary: Bluetooth device plugin for NetworkManager
Group: System Environment/Base
Requires: %{name} = %{version}-%{release}
Requires: NetworkManager-wwan = %{version}-%{release}
Requires: bluez >= 4.101-5
Obsoletes: NetworkManager < %{obsoletes_device_plugins}

%description bluetooth
This package contains NetworkManager support for Bluetooth devices.
%endif

%if %{with team}
%package team
Summary: Team device plugin for NetworkManager
Group: System Environment/Base
BuildRequires: teamd-devel
Requires: %{name} = %{version}-%{release}
Obsoletes: NetworkManager < 1.0.0

%description team
This package contains NetworkManager support for team devices.
%endif


%if %{with wifi}
%package wifi
Summary: Wifi plugin for NetworkManager
Group: System Environment/Base
Requires: %{name} = %{version}-%{release}
Requires: wireless-regdb

%if %{with iwd}
Requires: iwd
%endif

Obsoletes: NetworkManager < %{obsoletes_device_plugins}

%description wifi
This package contains NetworkManager support for Wifi and OLPC devices.
%endif


%if %{with wwan}
%package wwan
Summary: Mobile broadband device plugin for NetworkManager
Group: System Environment/Base
Requires: %{name} = %{version}-%{release}
Requires: ModemManager
Obsoletes: NetworkManager < %{obsoletes_device_plugins}

%description wwan
This package contains NetworkManager support for mobile broadband (WWAN)
devices.
%endif


%if %{with ovs}
%package ovs
Summary: Open vSwitch device plugin for NetworkManager
Group: System Environment/Base
Requires: %{name} = %{version}-%{release}
Requires: openvswitch

%description ovs
This package contains NetworkManager support for Open vSwitch bridges.
%endif


%if %{with ppp}
%package ppp
Summary: PPP plugin for NetworkManager
Group: System Environment/Base
Requires: %{name} = %{version}-%{release}
Requires: ppp = %{ppp_version}
Requires: NetworkManager = %{version}-%{release}
Obsoletes: NetworkManager < %{obsoletes_ppp_plugin}

%description ppp
This package contains NetworkManager support for PPP.
%endif

%package libnm
Summary: Libraries for adding NetworkManager support to applications.
Group: Development/Libraries
Conflicts: NetworkManager-glib < 1.31.0
License: LGPLv2+

%description libnm
This package contains the libraries that make it easier to use some
NetworkManager functionality from applications.

%package libnm-devel
Summary: Header files for adding NetworkManager support to applications.
Group: Development/Libraries
Requires: %{name}-libnm = %{version}-%{release}
Requires: glib2-devel
Requires: pkgconfig
License: LGPLv2+

%description libnm-devel
This package contains the header and pkg-config files for development
applications using NetworkManager functionality from applications.

%package config-server
Summary: NetworkManager config file for "server-like" defaults
Group: System Environment/Base
BuildArch: noarch

%description config-server
This adds a NetworkManager configuration file to make it behave more
like the old "network" service. In particular, it stops NetworkManager
from automatically running DHCP on unconfigured ethernet devices, and
allows connections with static IP addresses to be brought up even on
ethernet devices with no carrier.

This package is intended to be installed by default for server
deployments.

%package dispatcher-routing-rules
Summary: NetworkManager dispatcher file for advanced routing rules
Group: System Environment/Base
BuildArch: noarch
Provides: %{name}-config-routing-rules = %{version}-%{release}
Obsoletes: %{name}-config-routing-rules < 1.31.0

%description dispatcher-routing-rules
This adds a NetworkManager dispatcher file to support networking
configurations using "/etc/sysconfig/network-scripts/rule-NAME" files
(eg, to do policy-based routing).


%package tui
Summary: NetworkManager curses-based UI
Group: System Environment/Base
Requires: %{name} = %{version}-%{release}
Requires: %{name}-libnm = %{version}-%{release}

%description tui
This adds a curses-based "TUI" (Text User Interface) to
NetworkManager, to allow performing some of the operations supported
by nm-connection-editor and nm-applet in a non-graphical environment.


%if %{with nm_cloud_setup}
%package cloud-setup
Summary: Automatically configure NetworkManager in cloud
Group: System Environment/Base
Requires: %{name} = %{version}-%{release}
Requires: %{name}-libnm = %{version}-%{release}

%description cloud-setup
Installs a nm-cloud-setup tool that can automatically configure
NetworkManager in cloud setups. Currently only EC2 is supported.
This tool is still experimental.
%endif

%package initscripts-updown
Summary: Legacy ifup/ifdown scripts for NetworkManager that replace initscripts (network-scripts)
Group: System Environment/Base
BuildArch: noarch
Requires: NetworkManager
Requires: /usr/bin/nmcli

%description initscripts-updown
Installs alternative ifup/ifdown scripts that talk to NetworkManager.
This is only for backward compatibility with initscripts (network-scripts).
Preferably use nmcli instead.

%prep
%autosetup -p1 -n NetworkManager-%{real_version}

%build
autoreconf -fiv
%configure \
	--with-runstatedir=%{_rundir} \
	--disable-silent-rules \
	--disable-static \
	--with-nft=/usr/sbin/nft \
	--with-iptables=/usr/sbin/iptables \
	--with-dhclient=yes \
	--with-dhcpcd=no \
	--with-dhcpcanon=no \
	--with-config-dhcp-default=%{dhcp_default} \
	--with-crypto=gnutls \
	--disable-more-logging \
	--without-more-asserts \
	--enable-ld-gc \
	--enable-lto \
	--with-libaudit=yes-disabled-by-default \
%if 0%{?with_modem_manager_1}
	--with-modem-manager-1=yes \
%else
	--with-modem-manager-1=no \
%endif
%if %{with wifi}
	--enable-wifi=yes \
	--with-wext=yes \
%else
	--enable-wifi=no \
%endif
%if %{with iwd}
	--with-iwd=yes \
	--with-config-wifi-backend-default=iwd \
%else
	--with-iwd=no \
%endif
%if %{with bluetooth}
	--enable-bluez5-dun=yes \
%else
	--enable-bluez5-dun=no \
%endif
	--with-nmtui=yes \
%if %{with nm_cloud_setup}
	--with-nm-cloud-setup=yes \
%else
	--with-nm-cloud-setup=no \
%endif
%ifarch loongarch64
	--enable-vala=no \
%else
	--enable-vala=yes \
%endif
	--enable-introspection=yes \
	--enable-gtk-doc=no \
	--enable-gtk-doc-html=no \
%if %{with team}
	--enable-teamdctl=yes \
%else
	--enable-teamdctl=no \
%endif
%if %{with ovs}
	--enable-ovs=yes \
%else
	--enable-ovs=no \
%endif
	--with-selinux=yes \
	--enable-polkit=yes \
	--enable-modify-system=yes \
	--enable-concheck \
	--with-libpsl \
	--with-ebpf=%{ebpf_enabled} \
	--with-session-tracking=systemd \
	--with-suspend-resume=systemd \
	--with-system-ca-path=/etc/pki/tls/cert.pem \
	--with-dbus-sys-dir=%{dbus_sys_dir} \
	--with-tests=yes \
	--enable-more-warnings=yes \
	--with-valgrind=no \
	--enable-ifcfg-rh=yes \
	--enable-ifupdown=no \
%if %{with ppp}
	--with-pppd-plugin-dir=%{_libdir}/pppd/%{ppp_version} \
	--enable-ppp=yes \
%else
	--enable-ppp=no \
%endif
	--enable-firewalld-zone \
	--with-dist-version=%{version}-%{release} \
	--with-resolvconf=no \
	--with-netconfig=no \
	--with-config-dns-rc-manager-default=%{dns_rc_manager_default} \
	--with-config-logging-backend-default=%{logging_backend_default}

%make_build


%install
%make_install

cp %{SOURCE1} %{buildroot}%{_sysconfdir}/%{name}/
cp %{SOURCE2} %{buildroot}%{nmlibdir}/conf.d/

rm -f %{buildroot}%{_libdir}/*.la
rm -f %{buildroot}%{_libdir}/pppd/%{ppp_version}/*.la
rm -f %{buildroot}%{nmplugindir}/*.la

mkdir -p %{buildroot}%{_prefix}/src/debug/NetworkManager-%{real_version}
cp valgrind.suppressions %{buildroot}%{_prefix}/src/debug/NetworkManager-%{real_version}

touch %{buildroot}%{_sbindir}/ifup
touch %{buildroot}%{_sbindir}/ifdown
%find_lang %{name}

%check
%make_build check

%pre
if [ -f "%{_unitdir}/network-online.target.wants/NetworkManager-wait-online.service" ] ; then
    systemctl enable NetworkManager-wait-online.service || :
fi

%post
if [ -S /run/udev/control ]; then
    /usr/bin/udevadm control --reload-rules || :
    /usr/bin/udevadm trigger --subsystem-match=net || :
fi
%firewalld_reload

%systemd_post %{systemd_units}


%post initscripts-updown
if [ -f %{_sbindir}/ifup -a ! -L %{_sbindir}/ifup ]; then
    /usr/sbin/update-alternatives --remove ifup %{_libexecdir}/nm-ifup >/dev/null 2>&1 || :
else
    /usr/sbin/update-alternatives --install %{_sbindir}/ifup ifup %{_libexecdir}/nm-ifup 50 \
        --slave %{_sbindir}/ifdown ifdown %{_libexecdir}/nm-ifdown
fi

%if %{with nm_cloud_setup}
%post cloud-setup
%systemd_post %{systemd_units_cloud_setup}
%endif

%preun
if [ $1 -eq 0 ]; then
    /bin/systemctl --no-reload disable NetworkManager.service >/dev/null 2>&1 || :
fi
%systemd_preun NetworkManager-wait-online.service NetworkManager-dispatcher.service nm-priv-helper.service

%preun initscripts-updown
if [ $1 -eq 0 ]; then
    /usr/sbin/update-alternatives --remove ifup %{_libexecdir}/nm-ifup >/dev/null 2>&1 || :
fi

%if %{with nm_cloud_setup}
%preun cloud-setup
%systemd_preun %{systemd_units_cloud_setup}
%endif

%postun
/usr/bin/udevadm control --reload-rules || :
/usr/bin/udevadm trigger --subsystem-match=net || :
%firewalld_reload

%systemd_postun %{systemd_units}

%if %{with nm_cloud_setup}
%postun cloud-setup
%systemd_postun %{systemd_units_cloud_setup}
%endif

%files
%license COPYING COPYING.LGPL COPYING.GFDL
%doc NEWS AUTHORS README.md CONTRIBUTING.md
%{dbus_sys_dir}/org.freedesktop.NetworkManager.conf
%{dbus_sys_dir}/nm-dispatcher.conf
%{dbus_sys_dir}/nm-priv-helper.conf
%{dbus_sys_dir}/nm-ifcfg-rh.conf
%{_sbindir}/%{name}
%{_bindir}/nmcli
%{_datadir}/bash-completion/completions/nmcli
%dir %{_sysconfdir}/%{name}
%dir %{_sysconfdir}/%{name}/conf.d
%dir %{_sysconfdir}/%{name}/dispatcher.d
%dir %{_sysconfdir}/%{name}/dispatcher.d/pre-down.d
%dir %{_sysconfdir}/%{name}/dispatcher.d/pre-up.d
%dir %{_sysconfdir}/%{name}/dispatcher.d/no-wait.d
%dir %{_sysconfdir}/%{name}/dnsmasq.d
%dir %{_sysconfdir}/%{name}/dnsmasq-shared.d
%dir %{_sysconfdir}/%{name}/system-connections
%config(noreplace) %{_sysconfdir}/%{name}/NetworkManager.conf
%ghost %{_sysconfdir}/%{name}/VPN
%{_bindir}/nm-online
%{_libexecdir}/nm-dhcp-helper
%{_libexecdir}/nm-dispatcher
%{_libexecdir}/nm-initrd-generator
%{_libexecdir}/nm-daemon-helper
%{_libexecdir}/nm-priv-helper
%dir %{_libdir}/%{name}
%dir %{nmplugindir}
%{nmplugindir}/libnm-settings-plugin-ifcfg-rh.so
%exclude %{_mandir}/man1/nmtui*
%dir %{nmlibdir}
%dir %{nmlibdir}/conf.d
%dir %{nmlibdir}/dispatcher.d
%dir %{nmlibdir}/dispatcher.d/pre-down.d
%dir %{nmlibdir}/dispatcher.d/pre-up.d
%dir %{nmlibdir}/dispatcher.d/no-wait.d
%dir %{nmlibdir}/VPN
%dir %{nmlibdir}/system-connections
%{_mandir}/man1/*
%{_mandir}/man5/*
%{_mandir}/man7/nmcli-examples.7*
%{_mandir}/man8/nm-initrd-generator.8.gz
%{_mandir}/man8/NetworkManager.8.gz
%{_mandir}/man8/NetworkManager-dispatcher.8.gz
%{_mandir}/man8/NetworkManager-wait-online.service.8.gz
%dir %{_localstatedir}/lib/NetworkManager
%dir %{_sysconfdir}/sysconfig/network-scripts
%{_datadir}/dbus-1/system-services/org.freedesktop.nm_dispatcher.service
%{_datadir}/dbus-1/system-services/org.freedesktop.nm_priv_helper.service
%{_datadir}/polkit-1/actions/*.policy
%{_prefix}/lib/udev/rules.d/*.rules
%{_prefix}/lib/firewalld/zones/nm-shared.xml

# systemd service
%{_unitdir}/NetworkManager.service
%{_unitdir}/NetworkManager-wait-online.service
%{_unitdir}/NetworkManager-dispatcher.service
%{_unitdir}/nm-priv-helper.service
%dir %{_datadir}/doc/NetworkManager/examples
%{_datadir}/doc/NetworkManager/examples/server.conf

%if %{with adsl}
%files adsl
%{nmplugindir}/libnm-device-plugin-adsl.so
%else
%exclude %{nmplugindir}/libnm-device-plugin-adsl.so
%endif

%if %{with team}
%files team
%{nmplugindir}/libnm-device-plugin-team.so
%endif

%if %{with wwan}
%files wwan
%{nmplugindir}/libnm-device-plugin-wwan.so
%{nmplugindir}/libnm-wwan.so
%endif

%if %{with ovs}
%files ovs
%{nmplugindir}/libnm-device-plugin-ovs.so
%{_unitdir}/NetworkManager.service.d/NetworkManager-ovs.conf
%{_mandir}/man7/nm-openvswitch.7*
%endif

%if %{with ppp}
%files ppp
%{_libdir}/pppd/%{ppp_version}/nm-pppd-plugin.so
%{nmplugindir}/libnm-ppp-plugin.so
%endif

%if %{with bluetooth}
%files bluetooth
%{nmplugindir}/libnm-device-plugin-bluetooth.so
%endif

%if %{with wifi}
%files wifi
%{nmplugindir}/libnm-device-plugin-wifi.so
%endif

%files libnm -f %{name}.lang
%{_libdir}/libnm.so.*
%{_libdir}/girepository-1.0/NM-1.0.typelib

%files libnm-devel
%dir %{_includedir}/libnm
%{_includedir}/libnm/*.h
%{_libdir}/pkgconfig/libnm.pc
%{_libdir}/libnm.so
%{_datadir}/gir-1.0/NM-1.0.gir
%dir %{_datadir}/gtk-doc/html/libnm
%{_datadir}/gtk-doc/html/libnm/*
%dir %{_datadir}/gtk-doc/html/NetworkManager
%{_datadir}/gtk-doc/html/NetworkManager/*
%ifnarch loongarch64
%{_datadir}/vala/vapi/libnm.deps
%{_datadir}/vala/vapi/libnm.vapi
%endif
%{_datadir}/dbus-1/interfaces/*.xml

%files config-server
%dir %{nmlibdir}
%dir %{nmlibdir}/conf.d
%{nmlibdir}/conf.d/00-server.conf

%files tui
%{_bindir}/nmtui
%{_bindir}/nmtui-edit
%{_bindir}/nmtui-connect
%{_bindir}/nmtui-hostname
%{_mandir}/man1/nmtui*

%if %{with nm_cloud_setup}
%files cloud-setup
%{_libexecdir}/nm-cloud-setup
%{_unitdir}/nm-cloud-setup.service
%{_unitdir}/nm-cloud-setup.timer
%{nmlibdir}/dispatcher.d/90-nm-cloud-setup.sh
%{nmlibdir}/dispatcher.d/no-wait.d/90-nm-cloud-setup.sh
%{nmlibdir}/dispatcher.d/pre-up.d/90-nm-cloud-setup.sh
%{_mandir}/man8/nm-cloud-setup.8*
%endif

%files initscripts-updown
%{_libexecdir}/nm-ifup
%ghost %attr(755, root, root) %{_sbindir}/ifup
%{_libexecdir}/nm-ifdown
%ghost %attr(755, root, root) %{_sbindir}/ifdown

%changelog
* Tue Apr 15 2025 Tracker Robot <trackbot@opencloudos.tech> - 1.44.2-7
- [Type] bugfix
- [DESC] Apply patches from rpm-tracker
- [Bug Fix] 9c42177d0936f9cbfc0dcbfb994821dad8322ed7.patch: mptcp: fix error handling rp_filter when kernel dont support mptcp

* Fri Jan 17 2025 xiaoyunzhao <xiaoyunzhao@tencent.com> - 1.44.2-6
- Fix CVE-2024-3661

* Tue Nov 26 2024 xiaoyunzhao <xiaoyunzhao@tencent.com> - 1.44.2-5
- Fix CVE-2024-6501

* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.44.2-4
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Thu Sep 19 2024 kianli <kianli@tencent.com> - 1.44.2-3
- Add iproute-tc buildrequires for test-tc-linux test

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.44.2-2.3
- Rebuilt for loongarch release

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.44.2-2.2
- Rebuilt for loongarch release

* Tue Mar 19 2024 Wenlong Zhang <zhangwenlong@loongson.cn> - 1.44.2-2.1 
- disable vala for loongarch64

* Tue Mar 19 2024 Rebuild Robot <rebot@opencloudos.org> - 1.44.2-1.1
- Rebuilt for jansson

* Wed Jan 10 2024 kianli <kianli@tencent.com> - 1.44.2-1
- Upgrade to 1.44.2

* Fri Nov 24 2023 Zhao Zhen <jeremiazhao@tencent.com> - 1.44.0-7
- recoveried ppp wifi bluetooth team iwd ovs wwan modules support

* Thu Oct 12 2023 Miaojun Dong <zoedong@tencent.com> - 1.44.0-6
- Rebuild for curl-8.4.0

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.44.0-5
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Aug 11 2023 Shuo Wang <abushwang@tencent.com> - 1.44.0-1
- update to 1.44.0

* Wed May 10 2023 kianli <kianli@tencent.com> - 1.39.10-4
- Don't use ifcfg-rh as default configuration plugin

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.39.10-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.39.10-2
- Rebuilt for OpenCloudOS Stream 23

* Wed Jul 20 2022 Hu Zhongze <joshuahu@tencent.com> - 1.39.10-1
- Init build
